{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "add_af.py"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#add_af.cwl/input_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#add_af.cwl/output_filename"
                }
            ],
            "id": "#add_af.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#add_af.cwl/output_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "add_is_in_impact.py",
                "--include-assay"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--IMPACT_file",
                        "position": 3
                    },
                    "id": "#add_is_in_impact.cwl/IMPACT_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--input_file",
                        "position": 1
                    },
                    "id": "#add_is_in_impact.cwl/input_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output_file",
                        "position": 2
                    },
                    "id": "#add_is_in_impact.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#add_is_in_impact.cwl/IMPACT_col_added_file"
                }
            ],
            "id": "#add_is_in_impact.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "TSV file with gene labels and corresponding impact assays",
                    "id": "#main/IMPACT_gene_list"
                },
                {
                    "type": "string",
                    "doc": "(ANALYSIS_GENE_CNA_FILENAME; <project_id>.gene.cna.txt)",
                    "id": "#main/analysis_gene_cna_filename"
                },
                {
                    "type": "string",
                    "doc": "(ANALYSIS_MUTATIONS_FILENAME; <project_id>.muts.maf)",
                    "id": "#main/analysis_mutations_filename"
                },
                {
                    "type": "string",
                    "doc": "<project_id>.muts.share.maf",
                    "id": "#main/analysis_mutations_share_filename"
                },
                {
                    "type": "string",
                    "doc": "(ANALYSIS_SEGMENT_CNA_FILE; <project_id>.seg.cna.txt)",
                    "id": "#main/analysis_segment_cna_filename"
                },
                {
                    "type": "string",
                    "doc": "(ANALYSIS_SV_FILE; <project_id>.svs.maf)",
                    "id": "#main/analysis_sv_filename"
                },
                {
                    "type": "string",
                    "doc": "the version label of Roslin / Argos used to run the project analysis (ARGOS_VERSION_STRING)",
                    "id": "#main/argos_version_string"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "cbio_cna_data_filename (CBIO_CNA_DATA_FILENAME; data_CNA.txt) analysis_gene_cna_filename (ANALYSIS_GENE_CNA_FILENAME; <project_id>.gene.cna.txt): (FACETS_DIR)/*_hisens.cncf.txt",
                    "id": "#main/facets_hisens_cncf_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "cbio_segment_data_filename (CBIO_SEGMENT_DATA_FILENAME; <project_id>_data_cna_hg19.seg) analysis_segment_cna_filename (ANALYSIS_SEGMENT_CNA_FILE; <project_id>.seg.cna.txt): (FACETS_DIR)/*_hisens.seg",
                    "id": "#main/facets_hisens_seg_files"
                },
                {
                    "type": "string",
                    "doc": "the version label of this helix filter repo (HELIX_FILTER_VERSION; git describe --all --long)",
                    "id": "#main/helix_filter_version"
                },
                {
                    "default": true,
                    "type": "boolean",
                    "doc": "whether or not the project is an IMPACT project; should be the value 'True' if so, otherwise any other value means 'False' (IS_IMPACT)",
                    "id": "#main/is_impact"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "analysis_mutations_filename (ANALYSIS_MUTATIONS_FILENAME) cbio_mutation_data_filename (CBIO_MUTATION_DATA_FILENAME): (MAF_DIR)/*.muts.maf",
                    "id": "#main/mutation_maf_files"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "doc": "analysis_sv_filename (ANALYSIS_SV_FILE; <project_id>.svs.maf): (MAF_DIR)/*.svs.pass.vep.maf",
                    "id": "#main/mutation_svs_maf_files"
                },
                {
                    "type": "File",
                    "id": "#main/targets_list"
                }
            ],
            "steps": [
                {
                    "run": "#add_af.cwl",
                    "in": [
                        {
                            "source": "#main/add_maf_comment/output_file",
                            "id": "#main/add_af/input_file"
                        },
                        {
                            "source": "#main/analysis_mutations_filename",
                            "id": "#main/add_af/output_filename"
                        }
                    ],
                    "out": [
                        "#main/add_af/output_file"
                    ],
                    "id": "#main/add_af"
                },
                {
                    "run": "#add_is_in_impact.cwl",
                    "in": [
                        {
                            "source": "#main/IMPACT_gene_list",
                            "id": "#main/add_is_in_impact/IMPACT_file"
                        },
                        {
                            "source": "#main/add_af/output_file",
                            "id": "#main/add_is_in_impact/input_file"
                        },
                        {
                            "source": "#main/analysis_mutations_filename",
                            "id": "#main/add_is_in_impact/output_filename"
                        }
                    ],
                    "out": [
                        "#main/add_is_in_impact/IMPACT_col_added_file"
                    ],
                    "id": "#main/add_is_in_impact"
                },
                {
                    "run": "#concat_with_comments.cwl",
                    "in": [
                        {
                            "source": "#main/helix_filter_version",
                            "id": "#main/add_maf_comment/comment_value"
                        },
                        {
                            "valueFrom": "${ return [ inputs.some_file ]; }",
                            "id": "#main/add_maf_comment/input_files"
                        },
                        {
                            "source": "#main/analysis_mutations_filename",
                            "id": "#main/add_maf_comment/output_filename"
                        },
                        {
                            "source": "#main/concat_analysis_muts_maf/output_file",
                            "id": "#main/add_maf_comment/some_file"
                        }
                    ],
                    "out": [
                        "#main/add_maf_comment/output_file"
                    ],
                    "id": "#main/add_maf_comment"
                },
                {
                    "run": "#concat-tables.cwl",
                    "in": [
                        {
                            "valueFrom": "${ return true; }",
                            "id": "#main/concat_analysis_muts_maf/comments"
                        },
                        {
                            "source": "#main/muts_maf_filter/analysis_mutations_file",
                            "id": "#main/concat_analysis_muts_maf/input_files"
                        },
                        {
                            "source": "#main/analysis_mutations_filename",
                            "id": "#main/concat_analysis_muts_maf/output_filename"
                        }
                    ],
                    "out": [
                        "#main/concat_analysis_muts_maf/output_file"
                    ],
                    "id": "#main/concat_analysis_muts_maf"
                },
                {
                    "run": "#concat.cwl",
                    "in": [
                        {
                            "source": "#main/reduce_sig_figs_hisens_segs/output_file",
                            "id": "#main/concat_hisens_segs/input_files"
                        }
                    ],
                    "out": [
                        "#main/concat_hisens_segs/output_file"
                    ],
                    "id": "#main/concat_hisens_segs"
                },
                {
                    "run": "#maf_col_filter.cwl",
                    "in": [
                        {
                            "source": "#main/add_is_in_impact/IMPACT_col_added_file",
                            "id": "#main/filter_maf_cols/input_file"
                        },
                        {
                            "source": "#main/analysis_mutations_share_filename",
                            "id": "#main/filter_maf_cols/output_filename"
                        }
                    ],
                    "out": [
                        "#main/filter_maf_cols/output_file"
                    ],
                    "id": "#main/filter_maf_cols"
                },
                {
                    "run": "#concat_with_comments.cwl",
                    "in": [
                        {
                            "source": "#main/helix_filter_version",
                            "id": "#main/generate_analysis_svs_maf/comment_value"
                        },
                        {
                            "source": "#main/mutation_svs_maf_files",
                            "id": "#main/generate_analysis_svs_maf/input_files"
                        }
                    ],
                    "out": [
                        "#main/generate_analysis_svs_maf/output_file"
                    ],
                    "id": "#main/generate_analysis_svs_maf"
                },
                {
                    "run": "#copy_number.cwl",
                    "in": [
                        {
                            "source": "#main/facets_hisens_cncf_files",
                            "id": "#main/generate_cna_data/hisens_cncfs"
                        },
                        {
                            "valueFrom": "${ return inputs.output_cna_filename.replace(/\\.[^/.]+$/, \"\") + '.ascna.txt'; }",
                            "id": "#main/generate_cna_data/output_cna_ascna_filename"
                        },
                        {
                            "source": "#main/analysis_gene_cna_filename",
                            "id": "#main/generate_cna_data/output_cna_filename"
                        },
                        {
                            "valueFrom": "${ return inputs.output_cna_filename.replace(/\\.[^/.]+$/, \"\") + '.scna.txt'; }",
                            "id": "#main/generate_cna_data/output_cna_scna_filename"
                        },
                        {
                            "source": "#main/targets_list",
                            "id": "#main/generate_cna_data/targets_list"
                        }
                    ],
                    "out": [
                        "#main/generate_cna_data/output_cna_file"
                    ],
                    "id": "#main/generate_cna_data"
                },
                {
                    "run": "#put_in_dir.cwl",
                    "in": [
                        {
                            "valueFrom": "${ return [ inputs.gene_cna_file, inputs.muts_maf_file, inputs.muts_share_maf_file, inputs.hisens_segs, inputs.svs_maf_file ]}",
                            "id": "#main/make_analysis_dir/files"
                        },
                        {
                            "source": "#main/generate_cna_data/output_cna_file",
                            "id": "#main/make_analysis_dir/gene_cna_file"
                        },
                        {
                            "source": "#main/rename_analysis_hisens_segs/output_file",
                            "id": "#main/make_analysis_dir/hisens_segs"
                        },
                        {
                            "source": "#main/add_is_in_impact/IMPACT_col_added_file",
                            "id": "#main/make_analysis_dir/muts_maf_file"
                        },
                        {
                            "source": "#main/filter_maf_cols/output_file",
                            "id": "#main/make_analysis_dir/muts_share_maf_file"
                        },
                        {
                            "valueFrom": "${ return \"analysis\"; }",
                            "id": "#main/make_analysis_dir/output_directory_name"
                        },
                        {
                            "source": "#main/rename_analysis_svs_maf/output_file",
                            "id": "#main/make_analysis_dir/svs_maf_file"
                        }
                    ],
                    "out": [
                        "#main/make_analysis_dir/directory"
                    ],
                    "id": "#main/make_analysis_dir"
                },
                {
                    "run": "#maf_filter.cwl",
                    "scatter": "#main/muts_maf_filter/maf_file",
                    "in": [
                        {
                            "source": "#main/analysis_mutations_filename",
                            "id": "#main/muts_maf_filter/analysis_mutations_filename"
                        },
                        {
                            "source": "#main/argos_version_string",
                            "id": "#main/muts_maf_filter/argos_version_string"
                        },
                        {
                            "source": "#main/is_impact",
                            "id": "#main/muts_maf_filter/is_impact"
                        },
                        {
                            "source": "#main/mutation_maf_files",
                            "id": "#main/muts_maf_filter/maf_file"
                        }
                    ],
                    "out": [
                        "#main/muts_maf_filter/analysis_mutations_file"
                    ],
                    "id": "#main/muts_maf_filter"
                },
                {
                    "run": "#reduce_sig_figs.cwl",
                    "scatter": "#main/reduce_sig_figs_hisens_segs/input_file",
                    "in": [
                        {
                            "source": "#main/facets_hisens_seg_files",
                            "id": "#main/reduce_sig_figs_hisens_segs/input_file"
                        }
                    ],
                    "out": [
                        "#main/reduce_sig_figs_hisens_segs/output_file"
                    ],
                    "id": "#main/reduce_sig_figs_hisens_segs"
                },
                {
                    "run": "#cp.cwl",
                    "in": [
                        {
                            "source": "#main/concat_hisens_segs/output_file",
                            "id": "#main/rename_analysis_hisens_segs/input_file"
                        },
                        {
                            "source": "#main/analysis_segment_cna_filename",
                            "id": "#main/rename_analysis_hisens_segs/output_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_analysis_hisens_segs/output_file"
                    ],
                    "id": "#main/rename_analysis_hisens_segs"
                },
                {
                    "run": "#cp.cwl",
                    "in": [
                        {
                            "source": "#main/generate_analysis_svs_maf/output_file",
                            "id": "#main/rename_analysis_svs_maf/input_file"
                        },
                        {
                            "source": "#main/analysis_sv_filename",
                            "id": "#main/rename_analysis_svs_maf/output_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_analysis_svs_maf/output_file"
                    ],
                    "id": "#main/rename_analysis_svs_maf"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputSource": "#main/make_analysis_dir/directory",
                    "id": "#main/analysis_dir"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "cat"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "output.txt",
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cat.cwl/input_files"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#cat.cwl/output_file",
                    "outputBinding": {
                        "glob": "output.txt"
                    }
                }
            ],
            "id": "#cat.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "concat-tables.py",
                "--no-carriage-returns"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "--comments",
                        "position": 3
                    },
                    "id": "#concat-tables.cwl/comments"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#concat-tables.cwl/input_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "NA",
                    "inputBinding": {
                        "prefix": "-n",
                        "position": 2
                    },
                    "id": "#concat-tables.cwl/na_str"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-o",
                        "position": 1
                    },
                    "id": "#concat-tables.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#concat-tables.cwl/output_file"
                }
            ],
            "id": "#concat-tables.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#concat.cwl/input_files"
                }
            ],
            "steps": [
                {
                    "run": "#cat.cwl",
                    "in": [
                        {
                            "source": "#concat.cwl/get_data/output_file",
                            "id": "#concat.cwl/combine_header_and_data/data_files"
                        },
                        {
                            "source": "#concat.cwl/get_header/output_file",
                            "id": "#concat.cwl/combine_header_and_data/header"
                        },
                        {
                            "valueFrom": "${ var file_list = [inputs.header]; return file_list.concat(inputs.data_files); }",
                            "id": "#concat.cwl/combine_header_and_data/input_files"
                        }
                    ],
                    "out": [
                        "#concat.cwl/combine_header_and_data/output_file"
                    ],
                    "id": "#concat.cwl/combine_header_and_data"
                },
                {
                    "run": "#tail.cwl",
                    "in": [
                        {
                            "source": "#concat.cwl/strip_comments/output_file",
                            "id": "#concat.cwl/get_data/input_file"
                        },
                        {
                            "valueFrom": "${ return \"+2\"; }",
                            "id": "#concat.cwl/get_data/num_lines"
                        }
                    ],
                    "scatter": [
                        "#concat.cwl/get_data/input_file"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#concat.cwl/get_data/output_file"
                    ],
                    "id": "#concat.cwl/get_data"
                },
                {
                    "run": "#head.cwl",
                    "in": [
                        {
                            "valueFrom": "${ return inputs.input_files[0]; }",
                            "id": "#concat.cwl/get_header/input_file"
                        },
                        {
                            "source": "#concat.cwl/strip_comments/output_file",
                            "id": "#concat.cwl/get_header/input_files"
                        },
                        {
                            "valueFrom": "${ return \"1\"; }",
                            "id": "#concat.cwl/get_header/num_lines"
                        }
                    ],
                    "out": [
                        "#concat.cwl/get_header/output_file"
                    ],
                    "id": "#concat.cwl/get_header"
                },
                {
                    "run": "#strip.cwl",
                    "in": [
                        {
                            "source": "#concat.cwl/input_files",
                            "id": "#concat.cwl/strip_comments/input_file"
                        }
                    ],
                    "scatter": [
                        "#concat.cwl/strip_comments/input_file"
                    ],
                    "scatterMethod": "dotproduct",
                    "out": [
                        "#concat.cwl/strip_comments/output_file"
                    ],
                    "id": "#concat.cwl/strip_comments"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#concat.cwl/combine_header_and_data/output_file",
                    "id": "#concat.cwl/output_file"
                }
            ],
            "id": "#concat.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "concat_with_comments.sh"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "helix_filters_01",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#concat_with_comments.cwl/comment_label"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#concat_with_comments.cwl/comment_value"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#concat_with_comments.cwl/input_files"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output.txt",
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#concat_with_comments.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#concat_with_comments.cwl/output_file"
                }
            ],
            "id": "#concat_with_comments.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "python",
                "/usr/bin/facets-suite/facets",
                "geneLevel",
                "--cnaMatrix"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/roslin-variant-facets:1.6.3",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 3,
                        "prefix": "-f"
                    },
                    "id": "#copy_number.cwl/hisens_cncfs"
                },
                {
                    "type": "string",
                    "default": "data_CNA.ascna.txt",
                    "id": "#copy_number.cwl/output_cna_ascna_filename"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "data_CNA.txt",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-o"
                    },
                    "id": "#copy_number.cwl/output_cna_filename"
                },
                {
                    "type": "string",
                    "default": "data_CNA.scna.txt",
                    "id": "#copy_number.cwl/output_cna_scna_filename"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "--targetFile"
                    },
                    "id": "#copy_number.cwl/targets_list"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_cna_ascna_filename)"
                    },
                    "id": "#copy_number.cwl/output_cna_ascna_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_cna_filename)"
                    },
                    "id": "#copy_number.cwl/output_cna_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_cna_scna_filename)"
                    },
                    "id": "#copy_number.cwl/output_cna_scna_file"
                }
            ],
            "id": "#copy_number.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": "cp",
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#cp.cwl/input_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#cp.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#cp.cwl/output_file"
                }
            ],
            "id": "#cp.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "head"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "$(inputs.input_file.basename).head.txt",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#head.cwl/input_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-n",
                        "position": 1
                    },
                    "id": "#head.cwl/num_lines"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#head.cwl/output_file",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename).head.txt"
                    }
                }
            ],
            "id": "#head.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "maf_col_filter.py"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#maf_col_filter.cwl/input_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#maf_col_filter.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#maf_col_filter.cwl/output_file"
                }
            ],
            "id": "#maf_col_filter.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "maf_filter.py"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "analysis.muts.maf",
                    "inputBinding": {
                        "prefix": "--analyst-file",
                        "position": 4
                    },
                    "id": "#maf_filter.cwl/analysis_mutations_filename"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--version-string",
                        "position": 2
                    },
                    "id": "#maf_filter.cwl/argos_version_string"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "data_mutations_extended.txt",
                    "inputBinding": {
                        "prefix": "--portal-file",
                        "position": 5
                    },
                    "id": "#maf_filter.cwl/cbio_mutation_data_filename"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "--is-impact",
                        "position": 3
                    },
                    "id": "#maf_filter.cwl/is_impact"
                },
                {
                    "type": "boolean",
                    "default": true,
                    "inputBinding": {
                        "prefix": "--keep-rejects",
                        "position": 7
                    },
                    "id": "#maf_filter.cwl/keep_rejects"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#maf_filter.cwl/maf_file"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "rejected.muts.maf",
                    "inputBinding": {
                        "prefix": "--rejected-file",
                        "position": 6
                    },
                    "id": "#maf_filter.cwl/rejected_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.analysis_mutations_filename)"
                    },
                    "id": "#maf_filter.cwl/analysis_mutations_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.cbio_mutation_data_filename)"
                    },
                    "id": "#maf_filter.cwl/cbio_mutation_data_file"
                },
                {
                    "$import": "#maf_filter.cwl/rejected_file"
                }
            ],
            "id": "#maf_filter.cwl"
        },
        {
            "doc": "put all the items from a single list of Files or Directories into a new dir",
            "class": "ExpressionTool",
            "id": "#put_in_dir.cwl",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "inputs": [
                {
                    "doc": "a list of Files or Directories",
                    "type": {
                        "type": "array",
                        "items": [
                            "File",
                            "Directory",
                            "string",
                            "null"
                        ]
                    },
                    "id": "#put_in_dir.cwl/put-in-dir/files"
                },
                {
                    "type": "string",
                    "id": "#put_in_dir.cwl/put-in-dir/output_directory_name"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#put_in_dir.cwl/put-in-dir/directory"
                }
            ],
            "expression": "${\n  var output_files = [];\n  var input_files = inputs.files.filter(single_file => String(single_file).toUpperCase() != 'NONE');\n\n\n  for (var i = 0; i < inputs.files.length; i++) {\n    if(input_files[i]){\n      output_files.push(inputs.files[i]);\n    }\n  }\n\n  return {\n    'directory': {\n      'class': 'Directory',\n      'basename': inputs.output_directory_name,\n      'listing': output_files\n    }\n  };\n}\n"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "reduce_sig_figs_seg.mean.py"
            ],
            "stdout": "output.txt",
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#reduce_sig_figs.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#reduce_sig_figs.cwl/output_file",
                    "outputBinding": {
                        "glob": "output.txt"
                    }
                }
            ],
            "id": "#reduce_sig_figs.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "grep",
                "-v",
                "#"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "$(inputs.input_file.basename).strip.txt",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#strip.cwl/input_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#strip.cwl/output_file",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename).strip.txt"
                    }
                }
            ],
            "id": "#strip.cwl"
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "tail"
            ],
            "requirements": [
                {
                    "dockerPull": "mskcc/helix_filters_01:21.4.1",
                    "class": "DockerRequirement"
                }
            ],
            "stdout": "$(inputs.input_file.basename).tail.txt",
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#tail.cwl/input_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-n",
                        "position": 1
                    },
                    "id": "#tail.cwl/num_lines"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "id": "#tail.cwl/output_file",
                    "outputBinding": {
                        "glob": "$(inputs.input_file.basename).tail.txt"
                    }
                }
            ],
            "id": "#tail.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
